<?php

return [
    // Removed classes
    'RemoveXSS' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-76164-DeprecateRemoveXSS.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Console\Application' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-80468-CommandLineInterfaceCliKeysAndCli_dispatchphpsh.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Console\CliRequestHandler' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-80468-CommandLineInterfaceCliKeysAndCli_dispatchphpsh.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\Wizard\ColorpickerController' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-78899-FormEngineMethods.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Form\Container\SoloFieldContainer' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-76101-RemoveSoloFieldContainer.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Form\Wizard\SuggestWizard' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-78899-FormEngineMethods.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Form\Wizard\ValueSliderWizard' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Cache\CacheFactory' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-76370-DeprecateCacheFactory.rst',
        ],
    ],
    'TYPO3\CMS\Core\Controller\CommandLineController' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79265-CommandLineControllerAndCleanerCommand.rst',
        ],
    ],
    'TYPO3\CMS\Core\Http\AjaxRequestHandler' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-73352-DeprecateOld-schoolAJAXRequests.rst',
        ],
    ],
    'TYPO3\CMS\Core\Messaging\AbstractStandaloneMessage' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-77164-ErrorpageMessageAndAbstractStandaloneMessage.rst',
        ],
    ],
    'TYPO3\CMS\Core\Messaging\ErrorpageMessage' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-77164-ErrorpageMessageAndAbstractStandaloneMessage.rst',
        ],
    ],
    'TYPO3\CMS\Core\TimeTracker\NullTimeTracker' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-73185-DeprecateNullTimeTracker.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Utility\ArrayUtility' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-77732-ExtbaseArrayUtility.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\ViewHelpers\CaseViewHelper' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Breaking-69863-ChangesInViewHelpersPostFluidStandalone.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\ViewHelpers\SwitchViewHelper' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Breaking-69863-ChangesInViewHelpersPostFluidStandalone.rst',
        ],
    ],
    'TYPO3\CMS\Form\Domain\Model\FormElements\AdvancedPassword' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Breaking-79464-ExtFormRefactorFluidRendering.rst'
        ],
    ],
    'TYPO3\CMS\Form\ViewHelpers\Form\CheckboxViewHelper' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Form\ViewHelpers\Form\PlainTextMailViewHelper' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Http\EidRequestHandler' => [
        'restFiles' => [
            'Deprecation-83803-DeprecateEidRequestHandler.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Http\AjaxRequestHandler' => [
        'restFiles' => [
            'Deprecation-83853-BackendAjaxRequestHandler.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Page\FramesetRenderer' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-78217-FramesetAndFrame.rst',
        ],
    ],
    'TYPO3\CMS\Lowlevel\CleanerCommand' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-79265-CommandLineControllerAndCleanerCommand.rst',
        ],
    ],
    'TYPO3\CMS\Core\Database\DatabaseConnection' => [
        'restFiles' => [
            'Breaking-80929-TYPO3_DBMovedToExtension.rst',
        ],
    ],
    'TYPO3\CMS\Core\Database\PreparedStatement' => [
        'restFiles' => [
            'Breaking-80929-TYPO3_DBMovedToExtension.rst',
        ],
    ],
    'TYPO3\CMS\Core\Database\PostProcessQueryHookInterface' => [
        'restFiles' => [
            'Breaking-80929-TYPO3_DBMovedToExtension.rst',
        ],
    ],
    'TYPO3\CMS\Core\Database\PreProcessQueryHookInterface' => [
        'restFiles' => [
            'Breaking-80929-TYPO3_DBMovedToExtension.rst',
        ],
    ],
    'TYPO3\CMS\T3editor\Hook\TypoScriptTemplateInfoHook' => [
        'restFiles' => [
            'Breaking-81171-EditAbilityOfTypoScriptTemplateInEXTtstemplateRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Sv\Report\ServicesListReport' => [
        'restFiles' => [
            'Breaking-81536-MoveOfServicesListReportFromSvToReports.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Sv\AbstractAuthenticationService' => [
        'restFiles' => [
            'Breaking-81735-GetRidOfSysextsv.rst',
            'Breaking-81536-MoveOfServicesListReportFromSvToReports.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Sv\AuthenticationService' => [
        'restFiles' => [
            'Breaking-81735-GetRidOfSysextsv.rst',
            'Breaking-81536-MoveOfServicesListReportFromSvToReports.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Configuration\Exception\ContainerIsLockedException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Configuration\Exception\NoSuchFileException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Configuration\Exception\NoSuchOptionException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\InvalidMarkerException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\InvalidViewHelperException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\InvalidRequestTypeException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\RequiredArgumentMissingException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\InvalidCommandIdentifierException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\Container\Exception\CannotInitializeCacheException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\Container\Exception\TooManyRecursionLevelsException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\Exception\WrongScopeException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\InvalidClassException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\InvalidObjectConfigurationException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\InvalidObjectException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\ObjectAlreadyRegisteredException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\UnknownClassException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\UnknownInterfaceException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\UnresolvedDependenciesException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Persistence\Generic\Exception\CleanStateNotMemorizedException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Persistence\Generic\Exception\InvalidPropertyTypeException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Persistence\Generic\Exception\MissingBackendException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Property\Exception\FormatNotSupportedException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Property\Exception\InvalidFormatException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Property\Exception\InvalidPropertyException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Reflection\Exception\InvalidPropertyTypeException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Security\Exception\InvalidArgumentForRequestHashGenerationException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Security\Exception\SyntacticallyWrongRequestHashException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\InvalidUriPatternException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\InvalidOrNoRequestHashException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Validation\Exception\InvalidSubjectException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Validation\Exception\NoValidatorFoundException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\InvalidTemplateResourceException' => [
        'restFiles' => [
            'Deprecation-81600-UnusedExtbaseExceptions.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extensionmanager\Utility\DatabaseUtility' => [
        'restFiles' => [
            'Breaking-82148-DownloadSQLDumpDroppedInEM.rst',
        ],
    ],
    'TYPO3\CMS\Extensionmanager\ViewHelpers\DownloadExtensionDataViewHelper' => [
        'restFiles' => [
            'Breaking-82148-DownloadSQLDumpDroppedInEM.rst',
        ],
    ],
    'TYPO3\CMS\Install\Service\SqlExpectedSchemaService' => [
        'restFiles' => [
            'Breaking-82148-DownloadSQLDumpDroppedInEM.rst',
        ],
    ],
    'TYPO3\CMS\Install\Service\SqlSchemaMigrationService' => [
        'restFiles' => [
            'Breaking-82148-DownloadSQLDumpDroppedInEM.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Variables\CmsVariableProvider' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Important-82229-FluidImplementationOfCmsVariableProviderRemoved.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\FrontendEditing\FrontendEditingController' => [
        'restFiles' => [
            'Deprecation-86110-FrontendEditingController.rst',
        ],
    ],
    'TYPO3\CMS\Core\ExtDirect\ExtDirectDebug' => [
        'restFiles' => [
            'Breaking-37180-RemovedExtDirectDebugAndGLOBALSerror.rst',
        ],
    ],
    'TYPO3\CMS\Recordlist\RecordList\AbstractDatabaseRecordList' => [
        'restFiles' => [
            'Breaking-82334-AbstractRecordList.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\RecordList\AbstractRecordList' => [
        'restFiles' => [
            'Breaking-82334-AbstractRecordList.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Belog\Domain\Model\HistoryEntry' => [
        'restFiles' => [
            'Breaking-55298-DecoupledHistoryFunctionality.rst',
        ],
    ],
    'TYPO3\CMS\Belog\Domain\Repository\HistoryEntryRepository' => [
        'restFiles' => [
            'Breaking-55298-DecoupledHistoryFunctionality.rst',
        ],
    ],
    'TYPO3\CMS\Belog\ViewHelpers\HistoryEntryViewHelper' => [
        'restFiles' => [
            'Breaking-55298-DecoupledHistoryFunctionality.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Http\BackendModuleRequestHandler' => [
        'restFiles' => [
            'Breaking-82406-RoutingBackendModulesRunThroughRegularDispatcher.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Module\AbstractModule' => [
        'restFiles' => [
            'Breaking-82689-BackendAbstractWizardControllerNotExtendsAbstractModule.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\TypoScript\ConfigurationForm' => [
        'restFiles' => [
            'Deprecation-82725-DeprecateConfigurationForm.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst'
        ],
    ],
    'TYPO3\CMS\Lowlevel\View\ConfigurationView' => [
        'restFiles' => [
            'Deprecation-82744-RenameExtlowlevelViewToLowlevelController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Lowlevel\View\DatabaseIntegrityView' => [
        'restFiles' => [
            'Deprecation-82744-RenameExtlowlevelViewToLowlevelController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Object\Container\ClassInfo' => [
        'restFiles' => [
            'Breaking-57594-OptimizeReflectionServiceCacheHandling.rst',
            'Feature-57594-OptimizeReflectionServiceCacheHandling.rst'
        ],
    ],
    'TYPO3\CMS\Extbase\Object\Container\ClassInfoCache' => [
        'restFiles' => [
            'Breaking-57594-OptimizeReflectionServiceCacheHandling.rst',
            'Feature-57594-OptimizeReflectionServiceCacheHandling.rst'
        ],
    ],
    'TYPO3\CMS\Extbase\Object\Container\ClassInfoFactory' => [
        'restFiles' => [
            'Breaking-57594-OptimizeReflectionServiceCacheHandling.rst',
            'Feature-57594-OptimizeReflectionServiceCacheHandling.rst'
        ],
    ],
    'TYPO3\CMS\Extbase\Reflection\ClassReflection' => [
        'restFiles' => [
            'Breaking-57594-OptimizeReflectionServiceCacheHandling.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Reflection\MethodReflection' => [
        'restFiles' => [
            'Breaking-57594-OptimizeReflectionServiceCacheHandling.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Reflection\ParameterReflection' => [
        'restFiles' => [
            'Breaking-57594-OptimizeReflectionServiceCacheHandling.rst',
        ],
    ],
    'TYPO3\CMS\Backend\AjaxLoginHandler' => [
        'restFiles' => [
            'Deprecation-82805-RenamedAjaxLoginHandlerPHPClass.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Utility\ClientUtility' => [
        'restFiles' => [
            'Deprecation-82903-DeprecateClientUtility.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\Pagetree\ExtdirectTreeCommands' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Core\ExtDirect\ExtDirectApi' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Core\ExtDirect\ExtDirectRouter' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\ExtDirectNode' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\Pagetree\Commands' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\Pagetree\DataProvider' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\Pagetree\ExtdirectTreeDataProvider' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\Pagetree\PagetreeNode' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\Pagetree\PagetreeNodeCollection' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\Renderer\ExtJsJsonTreeRenderer' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Workspaces\Hooks\PagetreeCollectionsProcessor' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\SysNote\Domain\Model\SysNote' => [
        'restFiles' => [
            'Breaking-84055-MigrateSys_notesAwayFromExtbase.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Command\LanguageUpdateCommand' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Controller\LanguageController' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Domain\Model\Extension' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Domain\Model\Language' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Domain\Repository\ExtensionRepository' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Domain\Repository\LanguageRepository' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Exception' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Exception\Language' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Exception\Ter' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Exception\XmlParser' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Service\RegistryService' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Service\TerService' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\Service\TranslationService' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\View\AbstractJsonView' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\View\Language\ActivateLanguageJson' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\View\Language\DeactivateLanguageJson' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\View\Language\GetTranslationsJson' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\View\Language\RemoveLanguageJson' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\View\Language\UpdateLanguageJson' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],
    'TYPO3\CMS\Lang\View\Language\UpdateTranslationJson' => [
        'restFiles' => [
            'Breaking-84131-RemovedClassesOfLanguageExtension.rst',
        ],
    ],

    // Removed interfaces
    'TYPO3\CMS\Backend\Form\DatabaseFileIconsHookInterface' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\Pagetree\CollectionProcessorInterface' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\EditableNodeLabelInterface' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Tree\DraggableAndDropableNodeInterface' => [
        'restFiles' => [
            'Breaking-82426-ExtJSAndExtDirectRemoval.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Validation\Validator\RawValidator' => [
        'restFiles' => [
            'Breaking-80700-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-83503-DeprecateUnneededRawValidator.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Tests\Unit\Validation\Validator\AbstractValidatorTestcase' => [
        'restFiles' => [
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Deprecation-83511-DeprecateAbstractValidatorTestcase.rst',
        ],
    ],
    'TYPO3\CMS\Core\Package\DependencyResolver' => [
        'restFiles' => [
            'Deprecation-84109-DeprecateDependencyResolver.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Recordlist\RecordList' => [
        'restFiles' => [
            'Deprecation-84399-ClassRecordListRenamedToRecordListController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\T3editor\CodeCompletion' => [
        'restFiles' => [
            'Deprecation-84410-CodeCompletionRenamedToCodeCompletionController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Form\Wizard\ImageManipulationWizard' => [
        'restFiles' => [
            'Deprecation-84409-ImageManipulationWizardRenamedToImageManipulationController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\T3editor\TypoScriptReferenceLoader' => [
        'restFiles' => [
            'Deprecation-84411-TypoScriptReferenceLoaderRenamedToTypoScriptReferenceController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Utility\PhpOptionsUtility' => [
        'restFiles' => [
            'Deprecation-85102-PhpOptionsUtility.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Encoding\JavaScriptEncoder' => [
        'restFiles' => [
            'Deprecation-85120-JavaScriptEncoder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Page\ExternalPageUrlHandler' => [
        'restFiles' => [
            'Deprecation-85124-RedirectingUrlHandlerHookConcept.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Http\UrlHandlerInterface' => [
        'restFiles' => [
            'Deprecation-85124-RedirectingUrlHandlerHookConcept.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Log\Writer\RuntimeCacheWriter' => [
        'restFiles' => [
            'Deprecation-85687-DeprecateRuntimeCacheWriter.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\LoginFramesetController' => [
        'restFiles' => [
            'Deprecation-85707-LoginFramesetController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Integrity\DatabaseIntegrityCheck' => [
        'restFiles' => [
            'Deprecation-85727-DatabaseIntegrityCheckMovedToEXTlowlevel.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\SaltedPasswordService' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Deprecation-85761-SaltedPasswordService.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Service\FlexFormService' => [
        'restFiles' => [
            'Deprecation-85802-MoveFlexFormServiceFromEXTextbaseToEXTcore.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Crypto\PasswordHashing\Salt\ComposedPasswordHashInterface' => [
        'restFiles' => [
            'Deprecation-85804-SaltedPasswordHashClassDeprecations.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Crypto\PasswordHashing\Salt\AbstractComposedSalt' => [
        'restFiles' => [
            'Deprecation-85804-SaltedPasswordHashClassDeprecations.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Crypto\PasswordHashing\Utility\ExtensionManagerConfigurationUtility' => [
        'restFiles' => [
            'Deprecation-85804-SaltedPasswordHashClassDeprecations.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Crypto\PasswordHashing\Utility\SaltedPasswordsUtility' => [
        'restFiles' => [
            'Deprecation-85804-SaltedPasswordHashClassDeprecations.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\Argon2ISalt' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\BcryptSalt' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\BlowfishSalt' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Exception\InvalidSaltException' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\Md5Salt' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\SaltFactory' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\SaltInterface' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\Pbkdf2Salt' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\PhpassSalt' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\AbstractComposedSalt' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Salt\ComposedSaltInterface' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Utility\ExensionManagerConfigurationUtility' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Saltedpasswords\Utility\SaltedPasswordsUtility' => [
        'restFiles' => [
            'Deprecation-85833-ExtensionSaltedpasswordsMergedIntoCoreExtension.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Workspaces\Service\AutoPublishService' => [
        'restFiles' => [
            'Deprecation-86001-WorkspacesTasksMigratedToSymfonyCommands.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Workspaces\Task\AutoPublishTask' => [
        'restFiles' => [
            'Deprecation-86001-WorkspacesTasksMigratedToSymfonyCommands.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Workspaces\Task\CleanupPreviewLinkTask' => [
        'restFiles' => [
            'Deprecation-86001-WorkspacesTasksMigratedToSymfonyCommands.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extensionmanager\Command\ExtensionCommandController' => [
        'restFiles' => [
            'Deprecation-85996-ExtensionManagerCommandController.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\GraphicalMenuContentObject' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\Menu\ImageMenuContentObject' => [
        'restFiles' => [
            'Deprecation-85902-IMGMENUGMENU.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Command\CoreCommand' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Command\ExtbaseCommand' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Command\HelpCommand' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Command\HelpCommandController' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Cli\Command' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Cli\CommandArgumentDefinition' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Cli\CommandManager' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Cli\ConsoleOutput' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Cli\Request' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Cli\RequestBuilder' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Cli\RequestHandler' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Controller\CommandController' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\AmbiguousCommandIdentifierException' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\CommandException' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Exception\NoSuchCommandException' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Scheduler\FieldProvider' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Scheduler\Task' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Scheduler\TaskExecutor' => [
        'restFiles' => [
            'Deprecation-85977-ExtbaseCommandControllersAndCliAnnotation.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Resource\Service\UserStorageCapabilityService' => [
        'restFiles' => [
            'Deprecation-86109-ClassUserStorageCapabilityService.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Cache\Frontend\StringFrontend' => [
        'restFiles' => [
            'Deprecation-81434-StringCacheFrontendDeprecated.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Module\BaseScriptClass' => [
        'restFiles' => [
            'Deprecation-86225-ClassesBaseScriptClassAndAbstractFunctionModule.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Module\AbstractFunctionModule' => [
        'restFiles' => [
            'Deprecation-86225-ClassesBaseScriptClassAndAbstractFunctionModule.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Install\Updates\AbstractUpdate' => [
        'restFiles' => [
            'Deprecation-86366-MethodsInAbstractUpdate.rst'
        ],
    ],
    'TYPO3\CMS\Core\Resource\Utility\BackendUtility' => [
        'restFiles' => [
            'Deprecation-73585-DeprecateTYPO3CMSCoreResourceUtilityBackendUtilitygetFlashMessageForMissingFile.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\PageTitle\AltPageTitleProvider' => [
        'restFiles' => [
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Page\PageGenerator' => [
        'restFiles' => [
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\Utility\EidUtility' => [
        'restFiles' => [
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Compiler\TemplateCompiler' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Breaking-73046-AliasAbstractNode-ViewHelperNodeForBackwardsCompatibility.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Exception' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Parser\SyntaxTree\AbstractNode'=> [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Breaking-73046-AliasAbstractNode-ViewHelperNodeForBackwardsCompatibility.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Parser\InterceptorInterface' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Parser\SyntaxTree\NodeInterface' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Parser\SyntaxTree\RootNode' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Parser\SyntaxTree\ViewHelperNode' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\Rendering\RenderingContextInterface' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\AbstractConditionViewHelper' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Breaking-82414-RemoveCMSBaseViewHelperClasses.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\AbstractTagBasedViewHelper' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Breaking-82414-RemoveCMSBaseViewHelperClasses.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Breaking-82414-RemoveCMSBaseViewHelperClasses.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\ArgumentDefinition' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
            'Breaking-82414-RemoveCMSBaseViewHelperClasses.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\Exception' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\Exception\InvalidVariableException' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\Facets\ChildNodeAccessInterface' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\Facets\CompilableInterface' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\Facets\PostParseInterface' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\TagBuilder' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\TemplateVariableContainer' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\ViewHelperInterface' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\Core\ViewHelper\ViewHelperVariableContainer' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\View\Exception' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\View\Exception\InvalidSectionException' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Fluid\View\Exception\InvalidTemplateResourceException' => [
        'restFiles' => [
            'Deprecation-87277-FluidClassAliases.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Http\RequestHandlerInterface' => [
        'restFiles' => [
            'Important-87516-RemoveCoreHTTPRequestHandlerInterface.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\CreateFolderController' => [
        'restFiles' => [
            'Deprecation-87882-FileRelatedControllersMovedToEXTfilelist.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\EditFileController' => [
        'restFiles' => [
            'Deprecation-87882-FileRelatedControllersMovedToEXTfilelist.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\FileUploadController' => [
        'restFiles' => [
            'Deprecation-87882-FileRelatedControllersMovedToEXTfilelist.rst'
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\RenameFileController' => [
        'restFiles' => [
            'Deprecation-87882-FileRelatedControllersMovedToEXTfilelist.rst'
        ],
    ],
    'TYPO3\CMS\Backend\Controller\File\ReplaceFileController' => [
        'restFiles' => [
            'Deprecation-87882-FileRelatedControllersMovedToEXTfilelist.rst'
        ],
    ],
    'TYPO3\CMS\Core\Site\Entity\PseudoSite' => [
        'restFiles' => [
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Core\Site\PseudoSiteFinder' => [
        'restFiles' => [
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3\CMS\Lowlevel\Command\RteImagesCommand' => [
        'restFiles' => [
            'Breaking-88500-RTEImageHandlingFunctionalityDropped.rst'
        ],
    ],
    'TYPO3\CMS\Frontend\Page\PageRepository' => [
        'restFiles' => [
            'Deprecation-88746-PageRepositoryPHPClassMovedFromFrontendToCoreExtension.rst'
        ],
    ],
    'TYPO3\CMS\Frontend\Page\PageRepositoryGetPageHookInterface' => [
        'restFiles' => [
            'Deprecation-88746-PageRepositoryPHPClassMovedFromFrontendToCoreExtension.rst'
        ],
    ],
    'TYPO3\CMS\Frontend\Page\PageRepositoryGetPageOverlayHookInterface' => [
        'restFiles' => [
            'Deprecation-88746-PageRepositoryPHPClassMovedFromFrontendToCoreExtension.rst'
        ],
    ],
    'TYPO3\CMS\Frontend\Page\PageRepositoryGetRecordOverlayHookInterface' => [
        'restFiles' => [
            'Deprecation-88746-PageRepositoryPHPClassMovedFromFrontendToCoreExtension.rst'
        ],
    ],
    'TYPO3\CMS\Frontend\Page\PageRepositoryInitHookInterface' => [
        'restFiles' => [
            'Deprecation-88746-PageRepositoryPHPClassMovedFromFrontendToCoreExtension.rst'
        ],
    ],
    'TYPO3\CMS\Extbase\Configuration\AbstractConfigurationManager' => [
        'restFiles' => [
            'Breaking-88496-MethodGetSwitchableControllerActionsHasBeenRemoved.rst'
        ],
    ],
    'TYPO3\CMS\Adminpanel\ModuleApi\InitializableInterface' => [
        'restFiles' => [
            'Deprecation-88807-AdminPanelInitializableInterfaceHasBeenDeprecated.rst',
            'Feature-88807-AdminPanelRequestEnricherInterfaceHasBeenIntroduced.rst',
        ],
    ],
    'TYPO3\CMS\Core\Console\CommandRequestHandler' => [
        'restFiles' => [
            'Deprecation-88839-CLILowlevelRequestHandlers.rst',
        ],
    ],
    'TYPO3\CMS\Core\Console\RequestHandlerInterface' => [
        'restFiles' => [
            'Deprecation-88839-CLILowlevelRequestHandlers.rst',
        ],
    ],
    'TYPO3\CMS\Core\Localization\Parser\LocallangXmlParser' => [
        'restFiles' => [
            'Deprecation-89037-DeprecatedLocallangXmlParser.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Mvc\Controller\AbstractController' => [
        'restFiles' => [
            'Deprecation-89554-DeprecateTYPO3CMSExtbaseMvcControllerAbstractController.rst',
        ],
    ],
    'TYPO3\CMS\Core\Resource\ResourceFactoryInterface' => [
        'restFiles' => [
            'Deprecation-89577-FALSignalSlotHandlingMigratedToPSR-14Events.rst',
        ],
    ],
    'TYPO3\CMS\Core\Configuration\TsConfigParser' => [
        'restFiles' => [
            'Deprecation-89718-LegacyPageTSconfigParsingLowlevelAPI.rst',
        ],
    ],
    'TYPO3\CMS\Backend\Template\DocumentTemplate' => [
        'restFiles' => [
            'Deprecation-90421-DocumentTemplate.rst',
        ],
    ],
    'TYPO3\CMS\Felogin\Hooks\CmsLayout' => [
        'restFiles' => [
            'Deprecation-88740-ExtFeloginPibasePlugin.rst',
        ],
    ],
    'TYPO3\CMS\Felogin\Controller\FrontendLoginController' => [
        'restFiles' => [
            'Deprecation-88740-ExtFeloginPibasePlugin.rst',
        ],
    ],
    'TYPO3\CMS\FrontendLogin\Hooks\CmsLayout' => [
        'restFiles' => [
            'Deprecation-88740-ExtFeloginPibasePlugin.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\SignalSlot\Dispatcher' => [
        'restFiles' => [
            'Deprecation-90625-ExtbaseSignalSlotDispatcher.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Domain\Model\FileMount' => [
        'restFiles' => [
            'Deprecation-90686-ModelFileMount.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Domain\Model\StaticFileCollection' => [
        'restFiles' => [
            'Deprecation-90692-FileCollectionModels.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Domain\Model\FolderBasedFileCollection' => [
        'restFiles' => [
            'Deprecation-90692-FileCollectionModels.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Domain\Model\AbstractFileCollection' => [
        'restFiles' => [
            'Deprecation-90692-FileCollectionModels.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Property\TypeConverter\StaticFileCollectionConverter' => [
        'restFiles' => [
            'Deprecation-90692-FileCollectionModels.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Property\TypeConverter\FolderBasedFileCollectionConverter' => [
        'restFiles' => [
            'Deprecation-90692-FileCollectionModels.rst',
        ],
    ],
    'TYPO3\CMS\Extbase\Property\TypeConverter\AbstractFileCollectionConverter' => [
        'restFiles' => [
            'Deprecation-90692-FileCollectionModels.rst',
        ],
    ],
    'TYPO3\CMS\Frontend\ContentObject\ContentObjectGetSingleHookInterface' => [
        'restFiles' => [
            'Deprecation-90937-VariousHooksInContentObjectRenderer.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\AbstractBarChartWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\AbstractChartWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\AbstractCtaButtonWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\AbstractDoughnutChartWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\AbstractListWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\AbstractNumberWithIconWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\AbstractRssWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\AbstractWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\DocumentationGettingStartedWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\DocumentationTSconfigReferenceWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\T3GeneralInformation' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\T3NewsWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\T3SecurityAdvisoriesWidget' => [
        'restFiles' => [
            'Breaking-90660-RegistrationOfWidgetsChanged.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\AdditionalCssInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\AdditionalJavascriptInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\ButtonProviderInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\ChartDataProviderInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\EventDataProviderInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\ListDataProviderInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\NumberWithIconDataProviderInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\RequireJsModuleInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\WidgetConfigurationInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Widgets\Interfaces\WidgetInterface' => [
        'restFiles' => [
            'Breaking-91066-MovedInterfacesOfDashboard.rst',
        ],
    ],
    'TYPO3\CMS\Dashboard\Utility\ButtonUtility' => [
        'restFiles' => [
            'Breaking-91066-RemovedButtonUtility.rst',
        ],
    ],
];
